within projet_usine_maremotrice;

model La_Rance

  import Modelica.Units.SI.Height;
  import Modelica.Units.SI.Area;
  import Modelica.Units.SI.VolumeFlowRate;

  // Définition des constantes et paramètres
  constant Area surface_rance_0 = 4e3 "Surface minimale du bassin (m²)";
  
  parameter VolumeFlowRate water_flow_river = 1.8e1 "Débit volumique de la rivière (m³/s)";
  parameter Height h_initial = (12 + 4.5) / 2 "Hauteur initiale du bassin (m)";

  // Variables dynamiques
  Height h_la_rance(start = h_initial, fixed = true) "Hauteur d'eau dans le bassin (m)";
  VolumeFlowRate q_in "Débit volumique entrant (m³/s)";
  Area surface_rance "Surface variable du bassin (m²)";

  // Port acausal pour connecter le bassin
  interfaces.port_eau port_rance annotation(
    Placement(transformation(origin = {2, 0}, extent = {{-10, -10}, {10, 10}}), 
    iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}})));

equation
  // Calcul de la surface variable (simplification géométrique)
  surface_rance = surface_rance_0 + 1.37e2 * (h_la_rance - h_initial);

  // Calcul du débit volumique entrant
  q_in = water_flow_river + port_rance.q_eau;

  // Dynamique de la hauteur d’eau dans le bassin (conservation de masse)
  der(h_la_rance) = q_in / surface_rance;

  // Hauteur propagée via le port acausal
  port_rance.h = h_la_rance;

annotation(
    Icon(graphics = {
      Bitmap(fileName="rivière.jpg", 
             extent={{-100, -100}, {100, 100}})
    })
  );

annotation(
    uses(Modelica(version = "4.0.0")));
end La_Rance;
