within projet_usine_maremotrice;

model Mer
  import Modelica.Units.SI.Height;
  import Modelica.Units.SI.Frequency;

  // Paramètres des marées
  constant Height sea_mean_height = (12+4.5)/2 "Hauteur moyenne de la mer (m) (emeraudenature, EDF)";
  parameter Height sea_amplitude = sea_mean_height / 2 "Amplitude des marées (m)";
  parameter Frequency sea_frequency = 1e4 / 44700 "Fréquence des marées (Hz)";

  // Hauteur dynamique de la mer
  Height h_mer "Hauteur de la mer en fonction du temps";

  // Port acausal pour connecter la mer
  interfaces.port_eau port_mer annotation(
    Placement(transformation(origin = {-58, 0}, extent = {{-10, -10}, {10, 10}}), 
    iconTransformation(origin = {-102, -4}, extent = {{-10, -10}, {10, 10}})));
equation
  // Calcul de la hauteur de la mer en fonction du temps
  h_mer = sea_mean_height + sea_amplitude * sin(2 * Modelica.Constants.pi * sea_frequency * time);

  // Transmission de la hauteur via le port acausal
  port_mer.h = h_mer;

annotation(
    Icon(graphics = {Bitmap(origin = {-1, -1}, extent = {{-99, -99}, {99, 99}}, fileName = "modelica://projet_usine_maremotrice/mer.jpg")}),
    uses(Modelica(version = "4.0.0")));
end Mer;
