within projet_usine_maremotrice.composants;

model Turbine
  import Modelica.Units.SI.VolumeFlowRate;
  import Modelica.Units.SI.Power;
  import Modelica.Units.SI.Height;
  import Modelica.Units.SI.Energy;
  // Paramètres et constantes
  parameter Real g = 9.81 "Accélération gravitationnelle (9.81 m/s²)";
  parameter Real rendement_positif = 0.7 "Rendement élec/méca de la turbine (flux positif)";
  parameter Real rendement_negatif = 0.6 "Rendement élec/méca de la turbine (flux négatif)";
  parameter Real facteur = 1 "Facteur de conversion pour le flux";
  constant Real ro_eau = 1025 "Masse volumique de l'eau en kg/m³";

// Variables
  VolumeFlowRate q_water "Flux d'eau traversant la turbine (m³/s)";
  Power P "Puissance électrique en sortie de la turbine (W)";
  Energy E "Energie produite en J";
  Modelica.Blocks.Interfaces.RealInput in_turbine annotation(
    Placement(transformation(origin = {-98, 58}, extent = {{-20, -20}, {20, 20}}), iconTransformation(origin = {-98, 58}, extent = {{-20, -20}, {20, 20}})));
  interfaces.port_eau mer annotation(
    Placement(transformation(origin = {-88, 0}, extent = {{-10, -10}, {10, 10}}), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}})));
  interfaces.port_eau rance annotation(
    Placement(transformation(origin = {88, 0}, extent = {{-10, -10}, {10, 10}}), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}})));
  
equation

// Le flux d'eau traversant la turbine est imposé par q_impose_turbine
  q_water = in_turbine;
// Calcul de la puissance électrique en fonction du flux et de la hauteur
  P = if in_turbine >= 0 then
        rendement_positif * ro_eau * g * rance.h * q_water 
      else
        (-1) * rendement_negatif * ro_eau * g * mer.h * q_water; 
  der(E)=P ;
// Flux sortant via le port acausal principal

  mer.q_eau = q_water;
  rance.q_eau = - q_water;
annotation(
    Icon(graphics = {Bitmap( extent = {{-100, -100}, {100, 100}}, fileName = "modelica://projet_usine_maremotrice/composants/turbine.jpg")}),
    uses(Modelica(version = "4.0.0")));
end Turbine;
